//
// Created by daniel on 23.7.20.
//

#include "loader.h"

Loader::Loader(int argc, char * argv[])
        : m_FileInput(""),
          m_FileOutput(""),
          m_ScanValue(0),
          m_Mode(Generator::SCANCHAIN_NUMBER)
{
    for(int i=0; i<argc; ++i)
        m_Commands.push_back(argv[i]);
}

bool Loader::SetInput()
{
    if ( m_Commands.size() > 1 )
    {
        m_FileInput = m_Commands[1];
        return true;
    }
    return false;
}

bool Loader::SetParam()
{
    if ( m_Commands.size() < 4 )
        return false;

    if ( m_Commands[2]=="-scan_number" )
    {
        m_Mode = Generator::ScanChainsGenerateMode::SCANCHAIN_NUMBER;
    }
    else if ( m_Commands[2]=="-scan_size" )
    {
        m_Mode = Generator::ScanChainsGenerateMode::SCANCHAIN_SIZE;
    }
    else if ( m_Commands[2]=="-scan_random" )
    {
        m_Mode = Generator::ScanChainsGenerateMode::SCANCHAIN_RANDOM;
    }
    else
    {
        return false;
    }

    int arg = 0;
    try {
        arg = std::stoi(m_Commands[3]);
    } catch (const std::invalid_argument & ex) {
        throw ex;
    }
    m_ScanValue = arg;
    return true;
}

bool Loader::SetOutput()
{
    if ( m_Commands.size() == 4 )
        return true;

    if ( m_Commands.size() != 6)
        return false;

    if ( m_Commands[4] != "-name" )
        return false;

    m_FileOutput = m_Commands[5];
    return true;
}

bool Loader::Generate()
{
    FileManager manager;

    if ( !manager.Read(m_FileInput) )
        return false;

    if ( m_FileOutput == "" )
    {
        m_Generator.GenerateConfig(manager.GetModel(0)->GetInputs(), std::cout, m_ScanValue, m_Mode);
    }
    else
    {
    	if ( manager.GetModel(0)->GetInputs().size() < m_ScanValue )
    		return false;
    
        std::ofstream output(m_FileOutput);
        if ( !Generator::CheckFile(output) )
            return false;
        m_Generator.GenerateConfig(manager.GetModel(0)->GetInputs(), output, m_ScanValue, m_Mode);
    	output.close();
    }

    return true;
}

