//
// Created by daniel on 21.5.20.
//

#ifndef PROGRAM_DELAYCONSTRAINT_H
#define PROGRAM_DELAYCONSTRAINT_H

/*
 * --------------------------------------------
 * Blif file - Delay Constraints
 * --------------------------------------------
 *
 * A delay-constraint is used to specify parameters to more accurately compute the amount of time signals take to
 * propagate from one point to another in a model. A delay-constraint is one or more of :
 *
 * .area <area>
 * .delay <in-name> <phase> <load> <max-load> <brise> <drise> <bfall> <dfall>
 * .wire_load_slope <load>
 * .wire <wire-load-list>
 * .input_arrival <in-name> <rise> <fall> [<before-after> <event>]
 * .default_input_arrival <rise> <fall>
 * .output_required <out-name> <rise> <fall> [<before-after> <event>]
 * .default_output_required <rise> <fall>
 * .input_drive <in-name> <rise> <fall>
 * .default_input_drive <rise> <fall>
 * .max_input_load <load>
 * .default_max_input_load <load>
 * .output_load <out-name> <load>
 * .default_output_load <load>
 *
 * rise, fall, drive, and load are all floating point numbers giving the rise time, fall time, input drive, and output load.
 *
 * in-name is a primary input and out-name is a primary output.
 *
 * before-after can be one of f b, a g , corresponding to “before” or “after,” and event has the same format as the
 *
 * unparenthesized form of event-1 in a clock-constraint.
 *
 * .area sets the area of the model to be area.
 *
 * .delay sets the delay for input in-name. phase is one of “ INV ,” “ NONINV ,” or “ UNKNOWN ” for inverting, non-
 * inverting, or neither. max-load is a floating point number for the maximum load. brise, drise, bfall, and
 * dfall are floating point numbers giving the block rise, drive rise, block fall, and drive fall for in-name.
 *
 * .wire load slope sets the wire load slope for the model.
 *
 * .wire sets the wire loads for the model from the list of floating point numbers in the wire-load-list.
 *
 * .input arrival sets the input arrival time for the input in-name. If the optional arguments are specified, then the
 * input arrival time is relative to the event.
 *
 * .output required sets the output required time for the output out-name. If the optional arguments are specified,
 * then the output required time is relative to the event.
 *
 * .input drive sets the input drive for the input in-name.
 *
 * .max input load sets the maximum load that the input in-name can handle.
 *
 * .output load sets the output load for the output out-name.
 *
 * .default input arrival, .default output required, .default input drive, .default output load set the corresponding
 * default values for all the inputs/outputs whose values are not specifically set.
 *
 * There is no actual unit for all the timing and load numbers. Special attention should be given when specifying
 * and interpreting the values. The timing numbers are assumed to be in the same “unit” as the cycle-time in the
 * .cycle construct.
 *
 */

class DelayConstraint {
public:

private:
};

#endif //PROGRAM_DELAYCONSTRAINT_H
