//
// Created by daniel on 21.5.20.
//

#ifndef PROGRAM_LIBRARYGATE_H
#define PROGRAM_LIBRARYGATE_H

/*
 * --------------------------------------------
 * Blif file - Library Gate
 * --------------------------------------------
 *
 * A library-gate creates an instance of a technology-dependent logic gate and associates it with a node that represents
 * the output of the logic gate. The logic function of the gate and its known technology dependent delays, drives, etc.
 * are stored with the library-gate. A library-gate is one of the following:
 *
 * .gate <name> <formal-actual-list>
 * .mlatch <name> <formal-actual-list> <control> [<init-val>]
 *
 * name is the name of the .gate or .mlatch to instantiate. A gate or latch with this name must be present in the
 * current working library.
 *
 * formal-actual-list is a mapping between the formal parameters of name (the terminals of the library-gate) and
 * the actual parameters of the current model (any signals in this model). The format for a formal-actual-list
 * is a white-space-separated sequence of assignment statements of the form:
 * formal1=actual1 formal2=actual2 ...
 *
 * All of the formal parameters of name must be specified in the formal-actual-list and the single output of
 * name must be the last one in the list.
 *
 * control is the clocking signal for the mlatch, which can be either a .clock of the model, the output of any function
 * in the model, or the word “NIL” for no clock.
 *
 * init-val is the initial state of the mlatch, which can be one of f 0, 1, 2, 3 g . “2” stands for “don’t care” and “3” is
 * “unknown.” Unspecified, it is assumed “3.”
 *
 * A .gate refers to a two-level representation of an arbitrary input, single output gate in a library. A .gate appears
 * under a technology-independent interpretation as if it were a single logic-gate.
 *
 * A .mlatch refers to a latch (not necessarily a D flip flop) in a library. A .mlatch appears under a technology-
 * independent interpretation as if it were a single generic-latch and possibly a single logic-gate feeding the data
 * input of that generic-latch.
 *
 * .gates and .mlatches are used to describe circuits that have been implemented using a specific library of
 * standard logic functions and their technology-dependent properties. The library of library-gates must be read in
 * before a BLIF file containing .gate or .mlatch constructs is read in.
 *
 * The string name refers to a particular gate or latch in the library. The names “nand2,” “inv,” and “jk rising edge”
 * in the following examples are descriptive names for gates in the library. The following BLIF description:
 * .inputs v1 v2
 * .outputs j
 * .gate nand2 A=v1 B=v2 O=x
 * .gate inv A=x O=j
 * .end
 * # given: formals of this gate are A, B, O
 * # given: formals of this gate are A & O
 *
 * could also be specified in a technology-independent way (assuming “nand2” is a 2-input NAND gate and “inv” is
 * an INVERTER ) as follows:
 *
 * .inputs v1 v2
 * .outputs j
 * .names v1 v2 x
 * 0- 1
 * -0 1
 * .names x j
 * 0 1
 * .end
 *
 * Similarly:
 *
 * .inputs j kbar
 * .outputs out
 * .clock clk
 * .mlatch jk_rising_edge J=j K=k Q=q clk 1
 * .names q out
 * 0 1
 * .names kbar k
 * 0 1
 * .end
 * 5
 * # given: formals are J, K, Q
 *
 * could have been specified in a technology-independent way (assuming “jk rising edge” is a JK rising-edge-
 * triggered flip flop) as follows:
 *
 * .inputs j kbar
 * .outputs out
 * .clock clk
 * .latch temp q re clk 1
 * .names j k q temp
 * -01 1
 * 1-0 1
 * .names q out
 * 0 1
 * .names kbar k
 * 0 1
 * .end
 *
 */


class LibraryGate {
public:

private:
};

#endif //PROGRAM_LIBRARYGATE_H
