//
// Created by daniel on 23.7.20.
//

#include "iloader.h"
ILoader::ILoader(int argc, char * argv[])
        : Loader(argc, argv),
          m_FileScan(""),
          m_TestMode(false)
{
    m_Mode = Generator::ScanChainsGenerateMode::SCANCHAIN_UNDEFINED;
}


bool ILoader::SetParam()
{

    size_t size = m_Commands.size();
    if ( size < 2 || size > 7 )
        return false;
    if ( size == 2 )
        return true;

    if ( size == 3  || size == 5 || size == 7 )
    {
        if ( m_Commands[size-1] == "-test")
            m_TestMode = true;
        else
            return false;
    }

    if (size == 3)
    {
        m_ScanValue = 0;
        return true;
    }

    if ( m_Commands[2]=="-scan_number" )
        m_Mode = Generator::ScanChainsGenerateMode::SCANCHAIN_NUMBER;
    else if ( m_Commands[2]=="-scan_size" )
        m_Mode = Generator::ScanChainsGenerateMode::SCANCHAIN_SIZE;
    else if ( m_Commands[2]=="-scan_random" )
        m_Mode = Generator::ScanChainsGenerateMode::SCANCHAIN_RANDOM;
    else if ( m_Commands[2]=="-scan_name")
        m_FileScan = m_Commands[3];
    else
        return false;

    int arg = 0;
    if ( m_Commands[2] != "-scan_name")
    {
        try {
            arg = std::stoi(m_Commands[3]);
        } catch (const std::invalid_argument & ex) {
            throw ex;
        }
    }
    m_ScanValue = arg;

    return true;
}


bool ILoader::SetOutput()
{
    size_t size = m_Commands.size();

    if ( size <= 4 )
        return true;

    if ( m_TestMode )
        size--;

    if ( m_Commands[size-2] == "-name" )
       m_FileOutput = m_Commands[size-1];
    return true;
}


bool ILoader::Generate() {
    FileManager manager;

    if ( !manager.Read(m_FileInput) )
        return false;

    if ( m_FileScan == "" )
    {
        std::ofstream scanFile("scan.txt");
        if ( !Generator::CheckFile(scanFile) )
            return false;

        if ( m_Mode == Generator::SCANCHAIN_UNDEFINED )
        {
           for(auto const & input : manager.GetModel(0)->GetInputs())
               scanFile << input->GetName() << " ";
           scanFile << "\n";
        }
        else
        {
            m_Generator.GenerateConfig(manager.GetModel(0)->GetInputs(), scanFile, m_ScanValue, m_Mode);
        }
        scanFile.close();
        m_FileScan = "scan.txt";
    }


    if ( m_FileOutput=="" )
    {
        if ( m_TestMode )
            m_Generator.GenerateIllinoisTest(manager.GetModel(0), m_FileScan, std::cout);
        else
            m_Generator.GenerateIllinois(manager.GetModel(0), m_FileScan, std::cout);

    }
    else
    {
        std::ofstream output(m_FileOutput);
        if ( !Generator::CheckFile(output))
            return false;

        if (m_TestMode)
            m_Generator.GenerateIllinoisTest(manager.GetModel(0), m_FileScan, output);
        else
            m_Generator.GenerateIllinois(manager.GetModel(0), m_FileScan, output);

        output.close();
    }

    return true;
}
